@@ -1,3 +1,5 @@
+#!/usr/bin/python
+
 import numpy as np
 import sys
 import math
@@ -37,7 +39,7 @@ class site:
 
 def main():
 
-    start = time.time()
+    #start = time.time()
 
     config.readValues(sys.argv[1:])
     lattice = setup_program.setup()
@@ -71,6 +73,7 @@ def sim(lattice):
 #################
 ## Catastrophe ##
 #################
+
 def cat(lattice, gen):
     #This is the probability of catastrophe in any grid point
     #(including grid points that don't currently have any individuals) during this generation
@@ -367,6 +370,10 @@ def sel(num):
     
     else:
         s = np.random.gamma( shape = config.g_a, scale = config.g_b, size=num)
+        aa = np.where(s > 1) #restrict s to 0-1
+        s[aa] = 1
+        bb = np.where(s < 0)
+        s[bb] = 0
     return s
 
 #Selection changing in one population
@@ -377,19 +384,28 @@ def selChange(pop, selected_Positions, oldPopNe):
     p = pop.snps.freq [ selected_Positions ] / float(oldPopNe)
     q = 1 - p
     h_array = [ config.h ] * len(p)
+    h_array = np.array(h_array)
     w = 1 - (2*p*q*h_array*s) - ((q**2) * s)
-    A = (p**2 + (p*q*(1-h_array*s))) / w #A is the new introduced selected allele
+    w_zeros = np.where(w == 0)
+    w_good = np.where(w > 0)
+    w_good_1 = w_good[0]
+    w_good_2 = w_good_1.astype(int)
+    A = np.zeros(len(w))
+    A[w_good_2] = (p[w_good_2]**2 + (p[w_good_2]*q[w_good_2]*(1-h_array[w_good_2]*s[w_good_2]))) / w[w_good_2] #A is the new introduced selected allele
     nextGen = np.random.binomial(pop.ne, A)
+    #iii =  np.where(nextGen == min(nextGen))
     p = nextGen
-    h = np.where(p > pop.ne)
+    #hh = np.where(p < 0)
+    #p[hh] = 0
+    h = np.where(p > pop.ne) #Why is this here? What am I doing with this? 7 Oct 2014
     if len(h[0] > 0):
-        print("PROBLEM WITH SELECTION")
+        print("ERROR: PROBLEM WITH SELECTION")
         sys.exit()
     return p
 
-######################################
-#Growth
-#######################################
+#############
+## Growth  ##
+#############
 def growth(j,k,ne):
     
     if isinstance(config.rMean, (int, long, float, complex)):
@@ -555,16 +571,17 @@ def writeToFile(lattice, gen):
     
     if config.recordTrag != 0:
         aaa = config.allele_history[0]
-        for j in range(0,len(config.allele_history)):
-            aaa = np.vstack((aaa,config.allele_history[j]))
-        alleleFileName = str(config.outFile) + "ALLELEHISTORY.gen" + str(gen)
+        for j in range(0,len(config.allele_history)): #FIX THIS. Allele_history isn't a vector!
+            aaa1 = np.vstack((aaa,config.allele_history[j]))
+            aaa = np.around(aaa1, decimals=3) #6 October 2014 added
+        alleleFileName = str(config.outFile) + ".alleleHistory.gen" + str(gen)
         headerToWrite = 'gen siteNum genAlleleArose s '
         for i in range(0, len(config.populations)):
-            headerToWrite = headerToWrite + 'pop' + str(config.populations[i][0]) + str(config.populations[i][1]) + ' ' + 'pop' + str(config.populations[i][0]) + str(config.populations[i][1]) + 'ne '
+            headerToWrite = headerToWrite + 'pop' + str(config.populations[i][0]) + str(config.populations[i][1]) + 'Freq ' + 'pop' + str(config.populations[i][0]) + str(config.populations[i][1]) + 'Ne '
         headerToWrite = headerToWrite + "\n"
         with open(alleleFileName, 'w') as f:
             f.write(headerToWrite)
-            np.savetxt(f, aaa)
+            np.savetxt(f, aaa, fmt='%i', delimiter='\t')
         f.close()
         
         ##Writing to different types of files
@@ -586,7 +603,6 @@ def writeToFile(lattice, gen):
                     writeOutput.PLINK(lattice, x, y, indivMat, gen)
 
 
-
 #This is the standard boilerplate that calls the main() function.
 if __name__ == '__main__':
     main()
\ No newline at end of file
